const path = require("path");

const Koa = require("koa");
const KoaBody = require("koa-body");
const KoaStatic = require("koa-static");
const parameter = require("koa-parameter");

require("../config/env.config"); // 加载配置

const router = require("../routers"); // 加载路由
const { captureRouteOmit } = require("../middlewares/captureRouteOmit");
const errHandler = require("./errorHandler"); // 加载自定义异常

const app = new Koa();

app.use(
	KoaBody({
		multipart: true,
		formidable: {
			uploadDir: path.join(__dirname, "../../data/upload"),
			keepExtensions: true,
		},
		parsedMethods: ["POST", "PUT", "PATCH", "DELETE"],
	})
);
app.use(KoaStatic(path.join(__dirname, "../../public")));
app.use(parameter(app));

app.use(captureRouteOmit); // 兜底处理路由错误，是否要考虑koa-parameter错误
app.use(router.routes()).use(router.allowedMethods());

// 统一的错误处理
app.on("error", errHandler); // 监听全局异常事件

module.exports = app;
